# Local .terraform directory
**/.terraform/*

# .tfstate files
*.tfstate
*.tfstate.*

# Crash log files
crash.log
crash.*.log

# Exclude all .tfvars files, which are likely to contain sensitive data, such as
# password, private keys, and other secrets. These should not be part of version 
# control as they are data points which are potentially different between 
# environments.
*.tfvars
*.tfvars.json

# Ignore override files as they may contain sensitive information and should not be committed
override.tf
override.tf.json
*_override.tf
*_override.tf.json

# Include override files for build purposes
# !override.tf

# Ignore transient lock files created by terraform
.terraform.lock.hcl

# Ignore CLI configuration files
.terraformrc
terraform.rc
