#!/bin/bash

case "$1" in
  up)
    docker compose -f docker-compose.dev.yml up --build -d
    ;;
  down)
    docker compose -f docker-compose.dev.yml down
    ;;
  logs)
    docker compose -f docker-compose.dev.yml logs -f
    ;;
  prod-up)
    docker compose -f docker-compose.prod.yml up --build -d
    ;;
  *)
    echo "Usage: ./docker-helper.sh {up|down|logs|prod-up}"
    exit 1
    ;;
esac
