variable "instance_type" {
  description = "EC2 instance type"
  default     = "t3.micro"
}

variable "ami" {
  description = "Ubuntu AMI ID for the selected region"
  default     = "ami-061fe7df6ad657197"
}

variable "bucket_name" {
  description = "S3 bucket name"
}

variable "ec2_name" {
  description = "Name tag for EC2 instance"
}

variable "db_username" {
  description = "RDS Postgres username"
}

variable "db_password" {
  description = "RDS Postgres password"
  sensitive   = true
}

variable "aws_profile" {
  description = "AWS CLI profile name configured locally"
  default     = "{{ project_name }}"
}

variable "region" {
  description = "AWS region"
  default     = "us-east-1"
}
