output "ec2_public_ip" {
  value = aws_eip.static_ip.public_ip
}

output "s3_bucket_name" {
  value = aws_s3_bucket.media.bucket
}

output "rds_endpoint" {
  value       = aws_db_instance.postgres.endpoint
  description = "RDS instance endpoint (hostname)"
  sensitive   = true
}

output "rds_username" {
  value       = aws_db_instance.postgres.username
  sensitive   = true
}

output "rds_password" {
  value       = aws_db_instance.postgres.password
  sensitive   = true
}
