services:
  backend:
    image: {{ dockerhub_username|default('user') }}/{{ project_name|lower }}:backend-latest
    container_name: {{ project_name }}-backend
    ports:
      - "8000:8000"
    env_file:
      - backend/.env
    restart: always
