terraform {
  required_providers {
    aws = {
      source  = "hashicorp/aws"
      version = "~> 5.0"
    }
  }
}

provider "aws" {
  region = "us-east-1"
}

resource "aws_s3_bucket" "static_files" {
  bucket_prefix = "{{ project_name }}-static-"
}

output "s3_bucket_name" {
  value = aws_s3_bucket.static_files.id
}
